# DJ Press Documentation

Welcome to the documentation site for DJ Press. This is a work in progress, but the following key areas are mostly
complete:

- [Installation](installation.md)
- [Configuration](configuration.md)
- [URL Structure](url_structure.md)
- [Template Tags](templatetags.md)
- [Themes](themes.md)
- [Plugins](plugins.md)
- [Sitemap](sitemap.md)

## Table of Contents

```{toctree}
---
maxdepth: 2
---
installation
configuration
url_structure
templatetags
themes
plugins
sitemap
```
